Geometry Computations
=====================

Ellipse
-------

``colour.geometry``

.. currentmodule:: colour.geometry

.. autosummary::
    :toctree: generated/

    ellipse_coefficients_general_form
    ellipse_coefficients_canonical_form
    point_at_angle_on_ellipse
    ELLIPSE_FITTING_METHODS
    ellipse_fitting

**Ancillary Objects**

``colour.geometry``

.. autosummary::
    :toctree: generated/

    ellipse_fitting_Halir1998

Intersection
------------

``colour.geometry``

.. currentmodule:: colour.geometry

.. autosummary::
    :toctree: generated/

    extend_line_segment
    intersect_line_segments

**Ancillary Objects**

``colour.geometry``

.. autosummary::
    :toctree: generated/

    LineSegmentsIntersections_Specification

Primitives
----------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    PRIMITIVE_METHODS
    primitive

**Ancillary Objects**

``colour.geometry``

.. currentmodule:: colour.geometry

.. autosummary::
    :toctree: generated/

    MAPPING_PLANE_TO_AXIS
    primitive_grid
    primitive_cube

Primitive Vertices
------------------

``colour``

.. currentmodule:: colour

.. autosummary::
    :toctree: generated/

    PRIMITIVE_VERTICES_METHODS
    primitive_vertices

``colour.geometry``

.. currentmodule:: colour.geometry

.. autosummary::
    :toctree: generated/

    primitive_vertices_quad_mpl
    primitive_vertices_grid_mpl
    primitive_vertices_cube_mpl
    primitive_vertices_sphere

Hull Section
------------

``colour.geometry``

.. currentmodule:: colour.geometry

.. autosummary::
    :toctree: generated/

    hull_section
